@@ -1,5 +1,5 @@
 
-# $Id: Error.pm,v 1.10 2007/05/15 12:04:21 Daddy Exp $
+# $Id: Error.pm,v 1.12 2010-12-02 23:45:57 Martin Exp $
 
 =head1 NAME
 
@@ -24,17 +24,18 @@ actually being connected to any particular search engine.
 
 =head1 AUTHOR
 
-Martin Thurn <mthurn@cpan.org>
+Martin 'Kingpin' Thurn, C<mthurn at cpan.org>, L<http://tinyurl.com/nn67z>.
 
 =cut
 
 package WWW::Search::Null::Error;
 
 use strict;
+use warnings;
 
 use base 'WWW::Search';
 our
-$VERSION = do { my @r = (q$Revision: 1.10 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 1.12 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 our $MAINTAINER = q{Martin Thurn <mthurn@cpan.org>};
 
 sub _native_setup_search
